/*----------------------------------------------------------
  Module:  Convert::IBM390
  Functions:  packeb, unpackeb
----------------------------------------------------------*/

void    CF_packeb ( SV *, char *, AV *, char *, STRLEN * );
void    CF_unpackeb ( AV *, char *, SV *, char * );
